#include <SPI.h>
#include <TinyGPS++.h>
#include <SoftwareSerial.h>
#include <Adafruit_GFX.h>
#include <Adafruit_PCD8544.h>

/*
   This sample sketch demonstrates the normal use of a TinyGPS++ (TinyGPSPlus) object.
   It requires the use of SoftwareSerial, and assumes that you have a
   9600-baud serial GPS device hooked up on pins 5(rx) and 6(tx).
*/

// D4 - Serial clock out (CLK)
// D14 - Serial data out (DIN)
// D2 - Data/Command select (D/C)
// D15 - LCD chip select (CE)
// D16 - LCD reset (RST)
Adafruit_PCD8544 display = Adafruit_PCD8544(4, 14, 2, 15, 16);

static const int RXPin = 5, TXPin = 6;
static const uint32_t GPSBaud = 9600;

// The TinyGPS++ object
TinyGPSPlus gps;

// The serial connection to the GPS device
SoftwareSerial ss(RXPin, TXPin);

void setup()
{
	Serial.begin(115200);
	ss.begin(GPSBaud);

	display.begin();
	display.setContrast(65);	// Choose best contrast
	display.display(); 			// show splashscreen
	delay(20);
	display.clearDisplay();   	// clears the screen and buffer

}

void loop()
{
  // This sketch displays information every time a new sentence is correctly encoded.
  while (ss.available() > 0)
    if (gps.encode(ss.read()))
      displayInfo();

  if (millis() > 5000 && gps.charsProcessed() < 10)
  {
    Serial.println(F("No GPS detected: check wiring."));
    while(true);
  }
}

void displayInfo()
{
	display.clearDisplay();
	if (gps.location.isValid()){
		display.println("Lat/Lng: ");
		display.println(gps.location.lat(), 6);
		display.println(gps.location.lng(), 6);
	}
	else{
		display.println("INVALID");
	}

  display.println("Date/Time: ");
  if (gps.date.isValid()){
    display.print(gps.date.month());
    display.print(F("/"));
    display.print(gps.date.day());
    display.print(F("/"));
    display.println(gps.date.year());
  }
  else{
    display.print(F("INVALID"));
  }

  if (gps.time.isValid()){
	if (gps.time.hour() < 10) display.print(F("0"));
	display.print(gps.time.hour());
    display.print(F(":"));
    if (gps.time.minute() < 10) display.print(F("0"));
    display.print(gps.time.minute());
    display.print(F(":"));
    if (gps.time.second() < 10) display.print(F("0"));
    display.print(gps.time.second());
   }
  else{
    display.print(F("INVALID"));
  }
 	display.display();
}
